summaryrefslogtreecommitdiff
path: root/tests/document-output-stream.c
diff options
context:
space:
mode:
authorPerberos <[email protected]>2011-11-07 19:52:18 -0300
committerPerberos <[email protected]>2011-11-07 19:52:18 -0300
commit5ded9cba8563f336939400303d6a841d5089b107 (patch)
treec5676588cff26ba37e12369fe4de24b54e9f6682 /tests/document-output-stream.c
parentf00b3a11a199f9f85a4d46a600f9d14179b37dbf (diff)
downloadpluma-5ded9cba8563f336939400303d6a841d5089b107.tar.bz2
pluma-5ded9cba8563f336939400303d6a841d5089b107.tar.xz
renaming from gedit to pluma
Diffstat (limited to 'tests/document-output-stream.c')
-rwxr-xr-xtests/document-output-stream.c46
1 files changed, 23 insertions, 23 deletions
diff --git a/tests/document-output-stream.c b/tests/document-output-stream.c
index eb571680..033cf49a 100755
--- a/tests/document-output-stream.c
+++ b/tests/document-output-stream.c
@@ -1,27 +1,27 @@
/*
* document-output-stream.c
* This file is part of gedit
*
* Copyright (C) 2010 - Ignacio Casal Quinteiro
*
* gedit is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* gedit is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with gedit; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA 02110-1301 USA
*/
-#include "gedit-document-output-stream.h"
+#include "pluma-document-output-stream.h"
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <glib.h>
@@ -31,18 +31,18 @@ static void
test_consecutive_write (const gchar *inbuf,
const gchar *outbuf,
gsize write_chunk_len,
- GeditDocumentNewlineType newline_type)
+ PlumaDocumentNewlineType newline_type)
{
- GeditDocument *doc;
+ PlumaDocument *doc;
GOutputStream *out;
gsize len;
gssize n, w;
GError *err = NULL;
gchar *b;
- GeditDocumentNewlineType type;
+ PlumaDocumentNewlineType type;
- doc = gedit_document_new ();
- out = gedit_document_output_stream_new (doc);
+ doc = pluma_document_new ();
+ out = pluma_document_output_stream_new (doc);
n = 0;
@@ -61,7 +61,7 @@ test_consecutive_write (const gchar *inbuf,
g_assert_cmpstr (inbuf, ==, b);
g_free (b);
- type = gedit_document_output_stream_detect_newline_type (GEDIT_DOCUMENT_OUTPUT_STREAM (out));
+ type = pluma_document_output_stream_detect_newline_type (PLUMA_DOCUMENT_OUTPUT_STREAM (out));
g_assert (type == newline_type);
g_output_stream_close (out, NULL, &err);
@@ -81,39 +81,39 @@ test_consecutive_write (const gchar *inbuf,
static void
test_empty ()
{
- test_consecutive_write ("", "", 10, GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT);
- test_consecutive_write ("\r\n", "", 10, GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF);
- test_consecutive_write ("\r", "", 10, GEDIT_DOCUMENT_NEWLINE_TYPE_CR);
- test_consecutive_write ("\n", "", 10, GEDIT_DOCUMENT_NEWLINE_TYPE_LF);
+ test_consecutive_write ("", "", 10, PLUMA_DOCUMENT_NEWLINE_TYPE_DEFAULT);
+ test_consecutive_write ("\r\n", "", 10, PLUMA_DOCUMENT_NEWLINE_TYPE_CR_LF);
+ test_consecutive_write ("\r", "", 10, PLUMA_DOCUMENT_NEWLINE_TYPE_CR);
+ test_consecutive_write ("\n", "", 10, PLUMA_DOCUMENT_NEWLINE_TYPE_LF);
}
static void
test_consecutive ()
{
test_consecutive_write ("hello\nhow\nare\nyou", "hello\nhow\nare\nyou", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_LF);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_LF);
test_consecutive_write ("hello\rhow\rare\ryou", "hello\rhow\rare\ryou", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_CR);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_CR);
test_consecutive_write ("hello\r\nhow\r\nare\r\nyou", "hello\r\nhow\r\nare\r\nyou", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_CR_LF);
}
static void
test_consecutive_tnewline ()
{
test_consecutive_write ("hello\nhow\nare\nyou\n", "hello\nhow\nare\nyou", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_LF);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_LF);
test_consecutive_write ("hello\rhow\rare\ryou\r", "hello\rhow\rare\ryou", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_CR);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_CR);
test_consecutive_write ("hello\r\nhow\r\nare\r\nyou\r\n", "hello\r\nhow\r\nare\r\nyou", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_CR_LF);
}
static void
test_big_char ()
{
test_consecutive_write ("\343\203\200\343\203\200", "\343\203\200\343\203\200", 2,
- GEDIT_DOCUMENT_NEWLINE_TYPE_LF);
+ PLUMA_DOCUMENT_NEWLINE_TYPE_LF);
}
int main (int argc,
@@ -122,7 +122,7 @@ int main (int argc,
g_type_init ();
g_test_init (&argc, &argv, NULL);
- gedit_prefs_manager_app_init ();
+ pluma_prefs_manager_app_init ();
g_test_add_func ("/document-output-stream/empty", test_empty);
@@ -1,27 +1,27 @@
/*
* document-output-stream.c
- * This file is part of gedit
+ * This file is part of pluma
*
* Copyright (C) 2010 - Ignacio Casal Quinteiro
@@ -1,27 +1,27 @@
* Copyright (C) 2010 - Ignacio Casal Quinteiro
*
- * gedit is free software; you can redistribute it and/or modify
+ * pluma is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,27 +1,27 @@
* (at your option) any later version.
*
- * gedit is distributed in the hope that it will be useful,
+ * pluma is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -1,27 +1,27 @@
*
* You should have received a copy of the GNU General Public License
- * along with gedit; if not, write to the Free Software
+ * along with pluma; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA 02110-1301 USA